Class: WordsRubySdk::GetSectionPageSetupRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/words_ruby_sdk/models/requests/GetSectionPageSetupRequest.rb

Overview

Request model for get_section_page_setup operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, section_index, folder = nil, storage = nil, load_encoding = nil, password = nil) ⇒ GetSectionPageSetupRequest

Initializes a new instance.

Parameters:

  • name —

    The document name.

  • section_index —

    Section index

  • folder (defaults to: nil) —

    Original document folder.

  • storage (defaults to: nil) —

    File storage, which have to be used.

  • load_encoding (defaults to: nil) —

    Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.

  • password (defaults to: nil) —

    Password for opening an encrypted document.



56
57
58
59
60
61
62
63
# File 'lib/words_ruby_sdk/models/requests/GetSectionPageSetupRequest.rb', line 56

def initialize(name, section_index, folder = nil, storage = nil, load_encoding = nil, password = nil)
   self.name = name
   self.section_index = section_index
   self.folder = folder
   self.storage = storage
   self.load_encoding = load_encoding
   self.password = password
end

Instance Attribute Details

#folder ⇒ Object

Original document folder.



40
41
42
# File 'lib/words_ruby_sdk/models/requests/GetSectionPageSetupRequest.rb', line 40

def folder
  @folder
end

#load_encoding ⇒ Object

Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.



44
45
46
# File 'lib/words_ruby_sdk/models/requests/GetSectionPageSetupRequest.rb', line 44

def load_encoding
  @load_encoding
end

#name ⇒ Object

The document name.



36
37
38
# File 'lib/words_ruby_sdk/models/requests/GetSectionPageSetupRequest.rb', line 36

def name
  @name
end

#password ⇒ Object

Password for opening an encrypted document.



46
47
48
# File 'lib/words_ruby_sdk/models/requests/GetSectionPageSetupRequest.rb', line 46

def password
  @password
end

#section_index ⇒ Object

Section index



38
39
40
# File 'lib/words_ruby_sdk/models/requests/GetSectionPageSetupRequest.rb', line 38

def section_index
  @section_index
end

#storage ⇒ Object

File storage, which have to be used.



42
43
44
# File 'lib/words_ruby_sdk/models/requests/GetSectionPageSetupRequest.rb', line 42

def storage
  @storage
end