Method: WordsRubySdk::PostDrawingObjectRequest#initialize

Defined in:
lib/words_ruby_sdk/models/requests/PostDrawingObjectRequest.rb

#initialize(name, drawing_object, image_file, index, folder = nil, storage = nil, load_encoding = nil, password = nil, dest_file_name = nil, revision_author = nil, revision_date_time = nil, node_path = nil) ⇒ PostDrawingObjectRequest

Initializes a new instance.

Parameters:

  • name

    The document name.

  • drawing_object

    Drawing object parameters

  • image_file

    File with image

  • index

    Object’s index

  • folder (defaults to: nil)

    Original document folder.

  • storage (defaults to: nil)

    File storage, which have to be used.

  • load_encoding (defaults to: nil)

    Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.

  • password (defaults to: nil)

    Password for opening an encrypted document.

  • dest_file_name (defaults to: nil)

    Result name of the document after the operation. If this parameter is omitted then result of the operation will be saved as the source document.

  • revision_author (defaults to: nil)

    Initials of the author to use for revisions.If you set this parameter and then make some changes to the document programmatically, save the document and later open the document in MS Word you will see these changes as revisions.

  • revision_date_time (defaults to: nil)

    The date and time to use for revisions.

  • node_path (defaults to: nil)

    Path to node, which contains collection of drawing objects.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/words_ruby_sdk/models/requests/PostDrawingObjectRequest.rb', line 74

def initialize(name, drawing_object, image_file, index, folder = nil, storage = nil, load_encoding = nil, password = nil, dest_file_name = nil, revision_author = nil, revision_date_time = nil, node_path = nil)
   self.name = name
   self.drawing_object = drawing_object
   self.image_file = image_file
   self.index = index
   self.folder = folder
   self.storage = storage
   self.load_encoding = load_encoding
   self.password = password
   self.dest_file_name = dest_file_name
   self.revision_author = revision_author
   self.revision_date_time = revision_date_time
   self.node_path = node_path
end